![logo](https://raw.githubusercontent.com/uliegecsm/reprospect/refs/heads/main/docs/source/_static/logo.svg)

![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/uliegecsm/reprospect/build.yml)

[![PyPI - Version](https://img.shields.io/pypi/v/reprospect?color=blue)](https://pypi.org/project/reprospect/)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/reprospect)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/reprospect)

![PyPI - Downloads](https://img.shields.io/pypi/dd/reprospect)
![PyPI - Downloads](https://img.shields.io/pypi/dw/reprospect)
![PyPI - Downloads](https://img.shields.io/pypi/dm/reprospect)

[![JOSS](https://joss.theoj.org/papers/31d0b8cb561f2ae10c399e2373543e7f/status.svg)](https://joss.theoj.org/papers/31d0b8cb561f2ae10c399e2373543e7f)

# reprospect

`ReProspect` provides a framework for reproducible prospecting of CUDA applications.

See [the documentation](https://uliegecsm.github.io/reprospect/) for more information.
